'use strict';
let h   = require('heroku-cli-util');
let api = require('./shared.js');

module.exports = {
  topic: 'redis',
  command: 'maxmemory',
  needsApp: true,
  needsAuth: true,
  args: [{name: 'database', optional: true}],
  flags: [{name: 'policy', char: 'p', hasValue: true, optional: false}],
  description: 'set the key eviction policy',
  help: 'Set the key eviction policy when instance reaches its storage limit.',
  run: h.command(function* (context, heroku) {
    let addonsFilter = api.make_addons_filter(context.args.database);
    let addons = addonsFilter(yield heroku.apps(context.app).addons().list());
    if (addons.length === 0) {
      h.error('No redis databases found');
      process.exit(1);
    }
    let addon = addons[0];
    let config = yield api.request(context, addon.name + '/config', 'PATCH', { maxmemory_policy: context.flags.policy });
    console.log(`Max-memory policy for ${addon.name} (${addon.config_vars[0]}) set to ${config.maxmemory_policy.value}.`);
    console.log(config.maxmemory_policy.value +' '+ config.maxmemory_policy.values[config.maxmemory_policy.value] + '.');
  })
};
